@@ -838,6 +838,9 @@ class Askdata(SignUp):
         # Agent.__init__(self, self, slug=slug)
         return Agent(self, slug=slug, agent_id=agent_id)
 
+    def get_token(self, username, password):
+        return self._token
+
     def join(self, df:pd.DataFrame, with_query:str, workspace:str, how="inner", on=None, left_on=None, right_on=None, lang="en"):
 
         s = requests.Session()
